@@ -60,7 +60,8 @@ public:
 	Glib::ustring get_libparted_version() ;
 	Glib::ustring get_thread_status_message() ;
 
-	FileSystem * get_filesystem_object( const FILESYSTEM & filesystem ) ;
+	static FileSystem * get_filesystem_object( FILESYSTEM filesystem );
+	static bool supported_filesystem( FILESYSTEM fstype );
 	static bool filesystem_resize_disallowed( const Partition & partition ) ;
 private:
 	//detectionstuff..
@@ -191,7 +192,7 @@ private:
 	static PedExceptionOption ped_exception_handler( PedException * e ) ;
 
 	std::vector<FS> FILESYSTEMS ;
-	std::map< FILESYSTEM, FileSystem * > FILESYSTEM_MAP ;
+	static std::map< FILESYSTEM, FileSystem * > FILESYSTEM_MAP ;
 	std::vector<PedPartitionFlag> flags;
 	std::vector<Glib::ustring> device_paths ;
 	bool probe_devices ;
